Crate buffer

Crate buffer 

Structs

ConsumedBatch
A batch of entries read from object storage by the Consumer.
Consumer
Reads batches of ingested entries from object storage via a queue consumer.
ConsumerConfig
Configuration for a Consumer.
DurabilityWatcher
ManifestEntry
A single entry in the manifest.
ManifestView
Read-only view of a parsed buffer queue manifest.
Metadata
Per-range metadata attached to a batch by the buffer.
Producer
ProducerConfig
Configuration for a Producer.
WriteHandle

Enums

CompressionType
Compression algorithm applied to the record block of a data batch.
Error

Functions

parse_manifest
Parse a manifest from its binary representation.

Type Aliases

Result